@@ -33,7 +33,7 @@ def run_from_config(
         "args_s3": args_s3,
         "execution_date": execution_date,
         "amocrm_secrets": amocrm_secrets,
-        "is_auth": is_oauth2
+        "is_oauth2": is_oauth2
     }
 
     config_list = get_config_list(file_dir)
